# Change Log

All notable changes to this project will be documented in this file.

This project adheres to [Semantic Versioning](http://semver.org/).


## [Unreleased]

- No changes... yet!


## [1.0.0a2] - 2016-07-22

### Added

- Scraper.is_compatible_with(version) method (from @justjasongreen)
- Automate manifest checking by Travis CI (from @justjasongreen)

### Fixed

- Package version reported correctly when utilised within foreign SCM (from @justjasongreen)


## [1.0.0a1] - 2016-07-21

### Added

- Scrape a list of meets occurring on a given date (from @justjasongreen)
- Scrape a list of races occurring at a given meet (from @justjasongreen)
- Scrape a list of runners competing in a given race (from @justjasongreen)
- Scrape the horse associated with a given runner (from @justjasongreen)
- Scrape the jockey associated with a given runner (from @justjasongreen)
- Scrape the trainer associated with a given runner (from @justjasongreen)
- Scrape a list of performances associated with a given profile (from @justjasongreen)


## [1.0.0a0] - 2016-07-20

### Added

- Create Python package (from @justjasongreen)
- Implement DevOps support (from @justjasongreen)


[Unreleased]: https://github.com/justjasongreen/punters_client/compare/1.0.0a2...HEAD
[1.0.0a2]: https://github.com/justjasongreen/punters_client/compare/1.0.0a1...1.0.0a2
[1.0.0a1]: https://github.com/justjasongreen/punters_client/compare/1.0.0a0...1.0.0a1
[1.0.0a0]: https://github.com/justjasongreen/punters_client/tree/1.0.0a0
